# RGB control for A4Tech Bloody keyboard for Linux

> This script allows you to set the RGB backlight color on A4Tech Bloody keyboards.

### How to use:

- On the keyboard press `Fn` + `1`.
- Make sure you are a sudo user.
- Run the script.

### Optional arguments:
``` bash
-c    - color in hex format. Example: 00ff00 #green
-id_v - vendor id in hex format, default: 0x09DA  
-id_p - product id in hex format, default: 0xFA10  
```

